@@ -2,7 +2,7 @@
  * lsm.h -- global declarations for LSM utilities.
  *
  * Lars Wirzenius
- * "@(#)lsm:lsm.h,v 1.1.1.1 1994/07/24 16:36:03 liw Exp"
+ * "@(#)lsm:lsm.h,v 1.3 1994/11/11 19:14:49 wirzeniu Exp"
  */
 
 #ifndef lsm_h_included
@@ -15,7 +15,7 @@
 /*
  * Maximum number of fields in one entry.
  */
-#define MAX_FIELDS      32
+#define MAX_FIELDS      128
 
 /*
  * One entry.  The fields are identified by indexes; all entries have the
@@ -46,6 +46,6 @@ int lsm_read_one_entry(FILE *, long *, struct lsm_entry *);
 int lsm_read_database(FILE *, struct lsm_database *);
 int lsm_write_one_entry(FILE *, const struct lsm_entry *);
 int lsm_write_database(FILE *, struct lsm_database *);
-int lsm_check_entry(struct lsm_entry *);
+int lsm_check_entry(struct lsm_entry *, const char *);
 
 #endif
